@@ -67,7 +67,7 @@ def run_api(api_key, max_minutes, max_characters, max_items, language):
         for post in response_json:
             item = ET.SubElement(root, "item")
             ET.SubElement(item, "likes").text = get_likes(post)
-            ET.SubElement(item, "message").text = crop_message(remove_emoji(get_message(post)), max_characters)
+            ET.SubElement(item, "message").text = crop_message(remove_emoji(get_message(post)), max_characters, language_index)
             ET.SubElement(item, "created_time").text = parse_string_to_string(get_creation_date(post), DATETIME_FORMAT, datetime_format_new)
 
             thumbnail_url = get_media(post)
@@ -113,7 +113,7 @@ def get_message(post):
 
 
 def get_creation_date(post):
-    return post.get('created_at', '')[:-6]
+    return post.get('created_at', '')[:19]
 
 def get_likes(post):
     return post.get('likes', 0)
